==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/nb.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleri",
    "There was a problem reading files from this album" : "Det oppstod ett problem under lasting av filer fra dette albumet",
    "Aborting preview. Could not find the file" : "Avbryter visning. Fant ikke filen",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "No compatible server found at {remote}" : "Ingen kompatibel tjener ble funnet på {remote}",
    "Invalid server url" : "Ugyldig tjeneradresse",
    "Could not load the description" : "Klarte ikke å laste inn beskrivelsen",
    "Could not load the description: " : "Klarte ikke å laste inn beskrivelsen:",
    "Copyright" : "Opphavsrett",
    "Could not load the copyright notice: " : "Klarte ikke å laste inn notat om opphavsrett:",
    "Copyright notice" : "Notat om opphavsrett",
    "Link to copyright document" : "Lenke til dokument om opphavsrett",
    "This application may not work properly on your browser." : "Dette programmet virker kanskje ikke optimalt i nettleseren din.",
    "For an improved experience, please install one of the following alternatives" : "For en forbedret opplevelse, installer ett av følgende alternativer",
    "Your browser is not supported!" : "Nettleseren din støttes ikke!",
    "please install one of the following alternatives" : "installer ett av følgende alternativer",
    "Album cannot be shown" : "Kan ikke vise album",
    "No media files found" : "Finner ingen media-filer",
    "Upload pictures in the Files app to display them here" : "Last opp bilder i Filer-programmet for å vise dem her",
    "Upload new files via drag and drop or by using the [+] button above" : "Last opp nye filer med dra og slipp eller med [+]-knappen ovenfor",
    "Configuration error" : "Oppsettsfeil",
    "New" : "Ny",
    "Hide Album" : "Skjul album",
    "Could not hide album" : "Kunne ikke skjule album",
    "Error loading slideshow template" : "Feil ved lasting av mal for lysbildevisning",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Feil!</strong> Kunne ikke generere en forhånsvisning av denne filen. <br>Gå til neste bilde mens dette bildet fjernes fra visningen",
    "Next" : "Neste",
    "Play" : "Spill",
    "Pause" : "Pause",
    "Previous" : "Forrige",
    "Close" : "Lukk",
    "Download" : "Last ned",
    "Toggle background" : "Bytt bakgrunn",
    "Delete" : "Slett",
    "Share" : "Del",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "Upload" : "Last opp",
    "Error" : "Feil",
    "Error while sharing" : "Feil under deling",
    "Error while unsharing" : "Feil ved oppheving av deling",
    "Error while changing permissions" : "Feil ved endring av tillatelser",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Share with users or groups …" : "Del med brukere eller grupper…",
    "Share with users, groups or remote users …" : "Del med brukere, grupper eller eksterne brukere…",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Del med folk på andre tjenere ved å bruke deres sammenknyttede sky-ID brukernavn@eksempel.no/cloud",
    "Share link" : "Del lenke",
    "The public link will expire no later than {days} days after it is created" : "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
    "Link" : "Lenke",
    "Password protect" : "Passordbeskyttet",
    "Password" : "Passord",
    "Choose a password for the public link" : "Velg et passord for den offentlige lenken",
    "Allow editing" : "Tillat redigering",
    "Email link to person" : "E-postlenke til person",
    "Send" : "Send",
    "Set expiration date" : "Sett utløpsdato",
    "Expiration" : "Utløpsdato",
    "Expiration date" : "Utløpsdato",
    "This list is maybe truncated - please refine your search term to see more results." : "Listen er kanskje avkortet - forbedre søkeord for å få flere resultater.",
    "No users or groups found for {search}" : "Fant ingen brukere for {search}",
    "No users found for {search}" : "Ingen brukre funnet for {search}",
    "An error occured. Please try again" : "Det oppstod en feil. Prøv igjen",
    "Adding user..." : "Legger til bruker…",
    "group" : "gruppe",
    "remote" : "ekstern",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Error while retrieving shares" : "Feil under henting av delinger",
    "Unshare" : "Avslutt deling",
    "notify by email" : "Varsle på e-mail",
    "can share" : "kan dele",
    "can edit" : "kan redigere",
    "access control" : "tilgangskontroll",
    "create" : "opprette",
    "change" : "endre",
    "delete" : "slett",
    "Password protected" : "Passordbeskyttet",
    "Error unsetting expiration date" : "Feil ved nullstilling av utløpsdato",
    "Error setting expiration date" : "Kan ikke sette utløpsdato",
    "Sending ..." : "Sender…",
    "Email sent" : "E-post sendt",
    "Warning" : "Advarsel",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Sort by name" : "Sorter på navn",
    "Sort by date" : "Sorter på dato",
    "Cancel upload" : "Avbryt opplasting",
    "Album information" : "Album-informasjon",
    "File list" : "Filliste",
    "Sorry, this file could not be found." : "Beklager, denne filen ble ikke funnet.",
    "Reasons might be:" : "Mulige årsaker:",
    "the wrong file ID was provided" : "feil fil-ID ble angitt",
    "the file was removed" : "filen ble fjernet",
    "the file is corrupt" : "filen er ødelagt",
    "the encryption key is missing" : "krypteringsnøkkelen mangler",
    "Here is the error message returned by the server: " : "Her er feilmeldingen som ble returnert av tjeneren:",
    "For more information, please contact your friendly Nextcloud administrator." : "For mer informasjon, kontakt til vennlige Nextcloud-administrator.",
    "Sorry, but the server could not fulfill your request." : "Beklager, men tjeneren kunne ikke utføre forespørselen din.",
    "Possible reasons for the problem:" : "Mulige årsaker til problemet:",
    "a conflicting app was installed" : "en uforenelig program ble installert",
    "a required component is missing or was disconnected" : "en påkrevet komponent mangler eller var frakoblet",
    "the filesystem is not readable" : "filsystemet kan ikke leses",
    "Sorry, this link doesn't seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "the item was removed" : "elementet er fjernet",
    "the link has expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er avskrudd",
    "For more information, please ask the person who has sent you this link." : "For mer informasjon, spør personen som har sendt deg lenken.",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "Picture view" : "Bildevisning",
    "Gallery view" : "Gallerivisning"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/nb.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleri",
    "There was a problem reading files from this album" : "Det oppstod ett problem under lasting av filer fra dette albumet",
    "Aborting preview. Could not find the file" : "Avbryter visning. Fant ikke filen",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "No compatible server found at {remote}" : "Ingen kompatibel tjener ble funnet på {remote}",
    "Invalid server url" : "Ugyldig tjeneradresse",
    "Could not load the description" : "Klarte ikke å laste inn beskrivelsen",
    "Could not load the description: " : "Klarte ikke å laste inn beskrivelsen:",
    "Copyright" : "Opphavsrett",
    "Could not load the copyright notice: " : "Klarte ikke å laste inn notat om opphavsrett:",
    "Copyright notice" : "Notat om opphavsrett",
    "Link to copyright document" : "Lenke til dokument om opphavsrett",
    "This application may not work properly on your browser." : "Dette programmet virker kanskje ikke optimalt i nettleseren din.",
    "For an improved experience, please install one of the following alternatives" : "For en forbedret opplevelse, installer ett av følgende alternativer",
    "Your browser is not supported!" : "Nettleseren din støttes ikke!",
    "please install one of the following alternatives" : "installer ett av følgende alternativer",
    "Album cannot be shown" : "Kan ikke vise album",
    "No media files found" : "Finner ingen media-filer",
    "Upload pictures in the Files app to display them here" : "Last opp bilder i Filer-programmet for å vise dem her",
    "Upload new files via drag and drop or by using the [+] button above" : "Last opp nye filer med dra og slipp eller med [+]-knappen ovenfor",
    "Configuration error" : "Oppsettsfeil",
    "New" : "Ny",
    "Hide Album" : "Skjul album",
    "Could not hide album" : "Kunne ikke skjule album",
    "Error loading slideshow template" : "Feil ved lasting av mal for lysbildevisning",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Feil!</strong> Kunne ikke generere en forhånsvisning av denne filen. <br>Gå til neste bilde mens dette bildet fjernes fra visningen",
    "Next" : "Neste",
    "Play" : "Spill",
    "Pause" : "Pause",
    "Previous" : "Forrige",
    "Close" : "Lukk",
    "Download" : "Last ned",
    "Toggle background" : "Bytt bakgrunn",
    "Delete" : "Slett",
    "Share" : "Del",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "Upload" : "Last opp",
    "Error" : "Feil",
    "Error while sharing" : "Feil under deling",
    "Error while unsharing" : "Feil ved oppheving av deling",
    "Error while changing permissions" : "Feil ved endring av tillatelser",
    "Shared with you and the group {group} by {owner}" : "Delt med deg og gruppen {group} av {owner}",
    "Shared with you by {owner}" : "Delt med deg av {owner}",
    "Share with users or groups …" : "Del med brukere eller grupper…",
    "Share with users, groups or remote users …" : "Del med brukere, grupper eller eksterne brukere…",
    "Share link" : "Del lenke",
    "The public link will expire no later than {days} days after it is created" : "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
    "Link" : "Lenke",
    "Password protect" : "Passordbeskyttet",
    "Password" : "Passord",
    "Choose a password for the public link" : "Velg et passord for den offentlige lenken",
    "Allow editing" : "Tillat redigering",
    "Email link to person" : "E-postlenke til person",
    "Send" : "Send",
    "Set expiration date" : "Sett utløpsdato",
    "Expiration" : "Utløpsdato",
    "Expiration date" : "Utløpsdato",
    "This list is maybe truncated - please refine your search term to see more results." : "Listen er kanskje avkortet - forbedre søkeord for å få flere resultater.",
    "No users or groups found for {search}" : "Fant ingen brukere for {search}",
    "No users found for {search}" : "Ingen brukre funnet for {search}",
    "An error occurred (\"{message}\"). Please try again" : "En feil inntraff (\"{message}\"). Prøv igjen",
    "An error occurred. Please try again" : "En feil inntraff. Prøv igjen",
    "Adding user..." : "Legger til bruker…",
    "group" : "gruppe",
    "remote" : "ekstern",
    "Resharing is not allowed" : "Videre deling er ikke tillatt",
    "Error while retrieving shares" : "Feil under henting av delinger",
    "Unshare" : "Avslutt deling",
    "notify by email" : "Varsle på e-mail",
    "can share" : "kan dele",
    "can edit" : "kan redigere",
    "access control" : "tilgangskontroll",
    "create" : "opprette",
    "change" : "endre",
    "delete" : "slett",
    "Password protected" : "Passordbeskyttet",
    "Error unsetting expiration date" : "Feil ved nullstilling av utløpsdato",
    "Error setting expiration date" : "Kan ikke sette utløpsdato",
    "Sending…" : "Sender...",
    "Email sent" : "E-post sendt",
    "Warning" : "Advarsel",
    "shared by %s" : "delt av %s",
    "Direct link" : "Direkte lenke",
    "Add to your Nextcloud" : "Legg til i din Nextcloud",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Sort by name" : "Sorter på navn",
    "Sort by date" : "Sorter på dato",
    "Cancel upload" : "Avbryt opplasting",
    "Album information" : "Album-informasjon",
    "File list" : "Filliste",
    "Sorry, this file could not be found." : "Beklager, denne filen ble ikke funnet.",
    "Reasons might be:" : "Mulige årsaker:",
    "the wrong file ID was provided" : "feil fil-ID ble angitt",
    "the file was removed" : "filen ble fjernet",
    "the file is corrupt" : "filen er ødelagt",
    "the encryption key is missing" : "krypteringsnøkkelen mangler",
    "Here is the error message returned by the server: " : "Her er feilmeldingen som ble returnert av tjeneren:",
    "For more information, please contact your friendly Nextcloud administrator." : "For mer informasjon, kontakt til vennlige Nextcloud-administrator.",
    "Sorry, but the server could not fulfill your request." : "Beklager, men tjeneren kunne ikke utføre forespørselen din.",
    "Possible reasons for the problem:" : "Mulige årsaker til problemet:",
    "a conflicting app was installed" : "en uforenelig program ble installert",
    "a required component is missing or was disconnected" : "en påkrevet komponent mangler eller var frakoblet",
    "the filesystem is not readable" : "filsystemet kan ikke leses",
    "Sorry, this link doesn't seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "the item was removed" : "elementet er fjernet",
    "the link has expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er avskrudd",
    "For more information, please ask the person who has sent you this link." : "For mer informasjon, spør personen som har sendt deg lenken.",
    "Picture view" : "Bildevisning",
    "Gallery view" : "Gallerivisning",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Del med folk på andre tjenere ved å bruke deres sammenknyttede sky-ID brukernavn@eksempel.no/cloud",
    "An error occured. Please try again" : "Det oppstod en feil. Prøv igjen",
    "Sending ..." : "Sender…"
},
"nplurals=2; plural=(n != 1);");
